@@ -72,7 +72,14 @@ class AppConfig(BaseConfig):
         # and Last name, not even username. Making that field useless.
         (user, _) = User.objects.get_or_create(username='cms-user')
 
-        public = instance.page.publisher_public
+        if instance.placeholder is None:
+            return
+
+        public = instance.placeholder.page.publisher_public
+
+        if public is None:
+            return
+
         kwargs = dict(page=public, language=get_language())
         publishings = PublishHistory.objects.filter(**kwargs)
         if publishings.count() == 0:
